compose!() { /* proc-macro */ }Expand description
Create a code template and use it right after:
- Write the code, use ^0 ^1 .. ^N as placeholders
- Write the inserts: #0^1^..^N (numbers = any code)
- Here is the point of it: repeat 2. if necessary
compose!() { /* proc-macro */ }Create a code template and use it right after: